@@ -6,6 +6,10 @@
 #' pedigrees use the same data set, one of the pedigrees may be chosen as
 #' 'source', from which data is transferred to all the other pedigrees.
 #'
+#' By default, all markers are assumed to be unlinked. To accommodate linkage, a
+#' genetic map should be supplied with the argument `linkageMap`. This requires
+#' the software MERLIN to be installed.
+#'
 #' @param ... Pedigree alternatives. Each argument should be either a single
 #'   `ped` object or a list of such. The pedigrees may be named; otherwise they
 #'   are assigned names "H1", "H2", ... automatically.
@@ -23,9 +27,13 @@
 #'   an error.
 #' @param markers A vector of marker names or indices indicating which markers
 #'   should be included. If NULL (the default) all markers are used.
+#' @param linkageMap Either NULL (default), or a data frame with three columns:
+#'   chromosome; marker name; centiMorgan position. If given, it signifies to
+#'   the program that the markers are linked and invokes MERLIN for computing
+#'   the likelihoods.
 #' @param verbose A logical.
 #'
-#' @seealso [LRpower()]
+#' @seealso [LRpower()], [pedprobr::likelihoodMerlin()]
 #'
 #' @return A `LRresult` object, which is essentially a list with entries
 #'
@@ -75,8 +83,10 @@
 #' res = kinshipLR(peds)
 #' res$LRperMarker
 #' res$likelihoodsPerMarker
+#'
+#'
 #' @export
-kinshipLR = function(..., ref = NULL, source = NULL, markers = NULL, verbose = FALSE) {
+kinshipLR = function(..., ref = NULL, source = NULL, markers = NULL, linkageMap = NULL, verbose = FALSE) {
   st = proc.time()
 
   x = list(...)
@@ -112,7 +122,7 @@ kinshipLR = function(..., ref = NULL, source = NULL, markers = NULL, verbose = F
   else
     stop2("Invalid value for `ref`: ", ref)
   if(verbose)
-    message("Reference pedigree: ", ref)
+    cat("Reference pedigree: ", ref, "\n")
 
   if(is.null(source)) {
     # Identity peds without marker data
@@ -132,7 +142,7 @@ kinshipLR = function(..., ref = NULL, source = NULL, markers = NULL, verbose = F
     if(length(source) != 1)
       stop2("`source` must have length 1: ", source)
     if(verbose)
-      message("Source pedigree: ", source)
+      cat("Source pedigree: ", source, "\n")
     srcPed = x[[source]]
     if(is.null(srcPed))
       stop2("Unknown source pedigree: ", source)
@@ -154,7 +164,7 @@ kinshipLR = function(..., ref = NULL, source = NULL, markers = NULL, verbose = F
   }
 
   if(verbose)
-    message("Number of markers: ", length(markers))
+    cat("Number of markers: ", length(markers), "\n")
 
   # Fix hypothesis names
   hypnames = names(x)
@@ -169,7 +179,28 @@ kinshipLR = function(..., ref = NULL, source = NULL, markers = NULL, verbose = F
 
   names(x) = hypnames
 
-  # Break all loops (NB: would use rapply, but doesnt work since is.list(ped) = TRUE
+  ### Linked markers: call MERLIN
+  if(!is.null(linkageMap)) {
+    if(!checkMerlin())
+      stop2("Kinship analysis with linked markers requires MERLIN to be installed")
+
+    xLumped = lapply(x, lumpAlleles, verbose = verbose)
+
+    lnLik = vapply(xLumped, function(hyp)
+      likelihoodMerlin(hyp, markers = markers, linkageMap = linkageMap,
+                       logbase = exp(1), verbose = FALSE),
+      FUN.VALUE = 1)
+
+    LRtotal = exp(lnLik - lnLik[[refIdx]])
+    LRtotal = signif(LRtotal, 3)
+    names(LRtotal) = paste0(hypnames, ":", hypnames[refIdx])
+
+    return(structure(
+      list(LRtotal = LRtotal, lnLik = lnLik),
+      class = "LRresult"))
+  }
+
+  # Break all loops (NB: rapply() doesn't work here, since is.list(ped) = TRUE)
   breaklp = function(a) {
     if(is.pedList(a))
       return(lapply(a, breaklp))
@@ -181,7 +212,7 @@ kinshipLR = function(..., ref = NULL, source = NULL, markers = NULL, verbose = F
   x_loopfree = lapply(x, breaklp)
 
   # compute likelihoods
-  liks = lapply(x_loopfree, function(xx) likelihood(xx, markers))
+  liks = lapply(x_loopfree, function(xx) likelihood(xx, markers = markers))
   likelihoodsPerMarker = do.call(cbind, liks)
 
   # LR per marker and total
